#include "tao/Object_Loader.h"

TAO_BEGIN_VERSIONED_NAMESPACE_DECL

TAO_Object_Loader::~TAO_Object_Loader ()
{
}

TAO_END_VERSIONED_NAMESPACE_DECL
